#!/usr/bin/env vpshell

# This script demonstrates implicit and explicit signals.


# Sub-class the standard Dialog to demonstrate implicit signals.

class myDialog(vp.Dialog):
    # Note the strange magic used to call the super-class constructor.  This
    # ensures that all the arguments, however they are supplied, get passed as
    # expected.

    def __init__(self,*args,**kwds):
        apply(vp.Dialog.__init__,(self,) + args,kwds)

    # This method, because it has the same name as a signal, functions as a
    # slot that is implicitly connected to that signal.

    def clickedOk(self):
        print 'In clickedOk(), doing nothing'


# A Python function used as a slot for an explicit signal.

def slot1(sender):
    print 'In slot1(), will call slot2() next time instead'

    # Disconnect the signal from this function so that it won't be called the
    # next time the user presses the Ok button.

    vp.disconnect(sender,vp.Dialog.clickedOk,slot1)

    # Connect the signal to the other function so that it gets called the next
    # time the user presses the Ok button.

    vp.connect(sender,vp.Dialog.clickedOk,slot2)


# Another Python function used as a slot for an explicit signal.

def slot2(sender):
    print 'In slot2(), will return vp.Dialog.Ok'

    # This will complete the interaction with the dialog.

    sender.done(sender.Ok)


# Create the GUI in a function.  This means that any additional references we
# create will disappear automatically when the function returns.

def createGUI(appwin):
    # Create the dialog.  Note that the parent is always the first argument to
    # a constructor of a VeePee control so we usually supply it as a positional
    # argument rather than using the 'parent = ' notation.

    dlg = myDialog(appwin)

    # Create a label in the dialog.  Note that a reference to the Python object
    # is given to the parent (the dialog in this case) so there is no need for
    # us to keep a separate reference by assigning the result to a name.

    vp.Label(dlg,text = 'This dialog demonstrates the use of signals in VeePee.')

    # Explicitly connect the signal emitted when the Ok button is clicked to a
    # slot.  The signal emitted when the Cancel button is clicked isn't
    # connected to anything, so it's default action will be performed.

    vp.connect(dlg,vp.Dialog.clickedOk,slot1)

    # This is a modal dialog, so this won't return until the user has done
    # something.

    btn = dlg.interact()
    print 'Dialog returned:', btn


# First we create an application window for the default one created for us by
# the application.

appwin = vp.ApplicationWindow()

# Create and interact with the GUI.

createGUI(appwin)

# All the GUI controls still exist as children of the application window.
# Deleting this will tidy everything up.  If we didn't do this, and we ran the
# same script again in the same Python interpreter then we would get an error
# when we tried to create the default application window, because it was still
# in existence from the first time the script was run.

del appwin
